@@ -2,7 +2,6 @@ context("Tests the pre functions")
 
 
 test_that("Get previous results with airquality and pre function", {
-  suppressWarnings(RNGversion("3.1.0"))
   set.seed(42)
   #####
   # With learning rate
@@ -17,8 +16,8 @@ test_that("Get previous results with airquality and pre function", {
   
   #####
   # Without learning rate
+  set.seed(42)
   airq.ens <- pre(Ozone ~ ., data=airquality, learnrate = 0, ntrees = 10)
-  
   airq.ens <- airq.ens[!names(airq.ens) %in%  c(
     "formula", "modmat_formula", "modmat", "data")]
   airq.ens$glmnet.fit <- airq.ens$glmnet.fit["glmnet.fit"]
@@ -27,7 +26,6 @@ test_that("Get previous results with airquality and pre function", {
   
   #####
   # Works only with rules
-  suppressWarnings(RNGversion("3.1.0"))
   set.seed(42)
   airq.ens <- pre(Ozone ~ ., data = airquality, type="rules", ntrees = 10)
   airq.ens <- airq.ens[!names(airq.ens) %in%  c(
@@ -38,7 +36,6 @@ test_that("Get previous results with airquality and pre function", {
   
   ####
   # Works with multivariate responses
-  suppressWarnings(RNGversion("3.1.0"))
   set.seed(42)
   airq.ens <- pre(Ozone + Solar.R ~ ., data = airquality, family = "mgaussian", ntrees = 10)
   airq.ens <- airq.ens[!names(airq.ens) %in%  c(
@@ -52,7 +49,6 @@ test_that("Get previous results with airquality and pre function", {
 test_that("Get previous results with PimaIndiansDiabetes and pre function", {
   #####
   # Without learning rate
-  suppressWarnings(RNGversion("3.1.0"))
   set.seed(7385056)
   fit <- pre(diabetes ~ ., data = PimaIndiansDiabetes, ntrees = 10, maxdepth = 3)
   
@@ -67,7 +63,6 @@ test_that("Get previous results with PimaIndiansDiabetes and pre function", {
   
   #####
   # With learning rate
-  suppressWarnings(RNGversion("3.1.0"))
   set.seed(4989935)
   fit <- pre(diabetes ~ ., data = PimaIndiansDiabetes, learnrate = .01,
              ntrees = 10, maxdepth = 3)
@@ -86,7 +81,6 @@ test_that("Get previous results with iris and pre function", {
   
   #####
   # With learning rate
-  suppressWarnings(RNGversion("3.1.0"))
   set.seed(7385056)
   fit <- pre(Species ~ ., data = iris, ntrees = 10, maxdepth = 3)
   
@@ -107,7 +101,6 @@ test_that("Get previous results with iris and pre function", {
     ##
     #####
     # Without learning rate
-    suppressWarnings(RNGversion("3.1.0"))
     set.seed(4989935)
     fit <- pre(Species ~ ., data = iris, learnrate = 0, ntrees = 10, maxdepth = 3, nlambda =10)
     
@@ -126,7 +119,6 @@ test_that("Get previous results with iris and pre function", {
     library("doParallel")
     cl <- makeCluster(2)
     registerDoParallel(cl)
-    suppressWarnings(RNGversion("3.1.0"))
     set.seed(4989935)
     fit2 <- pre(Species ~ ., data = iris, learnrate = 0, ntrees = 10, maxdepth = 3, par.init=TRUE, par.final=TRUE, nlambda = 10)
     stopCluster(cl)
@@ -143,27 +135,25 @@ test_that("Get previous results with iris and pre function", {
   }
 })
 
-
 test_that("Get previous results with lung survival data", {
-  suppressWarnings(RNGversion("3.1.0"))
-  set.seed(42)
-  fit <- pre(Surv(time, status) ~ ., data = Lung, ntrees = 10, family = "cox")
-  fit <- fit[names(fit) %in%  c("rules", "glmnet.fit")]
-  fit$call <- NULL
-  fit$glmnet.fit <- fit$glmnet.fit["glmnet.fit"]
-  fit$glmnet.fit$glmnet.fit <- fit$glmnet.fit$glmnet.fit["beta"]
-  fit$rules <- as.matrix(fit$rules)
-  # save_to_test(fit, "lung_w_pre_surv")
-  expect_equal(fit, read_to_test("lung_w_pre_surv"), tolerance = 1.490116e-06)
+  if (packageVersion("glmnet") < "3.0.0") {
+    set.seed(42)
+    fit <- pre(Surv(time, status) ~ ., data = Lung, ntrees = 10, family = "cox")
+    fit <- fit[names(fit) %in%  c("rules", "glmnet.fit")]
+    fit$call <- NULL
+    fit$glmnet.fit <- fit$glmnet.fit["glmnet.fit"]
+    fit$glmnet.fit$glmnet.fit <- fit$glmnet.fit$glmnet.fit["beta"]
+    fit$rules <- as.matrix(fit$rules)
+    # save_to_test(fit, "lung_w_pre_surv")
+    expect_equal(fit, read_to_test("lung_w_pre_surv"), tolerance = 1.490116e-06)
+  }
 })
 
 test_that("pre gives almost the same rules with `sparse` set to `TRUE` and `FALSE`", {
   #####
   # With learning rate
-  suppressWarnings(RNGversion("3.1.0"))
   set.seed(seed <- 42)
   airq.ens <- pre(Ozone ~ ., data=airquality, ntrees = 10)
-  suppressWarnings(RNGversion("3.1.0"))
   set.seed(seed)
   airq.ens.sparse <- pre(Ozone ~ ., data=airquality, ntrees = 10, sparse = TRUE)
   
@@ -180,18 +170,17 @@ test_that("pre gives almost the same rules with `sparse` set to `TRUE` and `FALS
   expect_equal(predict(airq.ens), predict(airq.ens.sparse))
   
   # check the classes of their model matrices
-  expect_equal(class(airq.ens$modmat), "matrix")
+  expect_equal(inherits(airq.ens$modmat, "matrix"), TRUE)
   expect_s4_class(airq.ens.sparse$modmat, "dgCMatrix")
 })
 
 test_that("predict.pre works with `sparse` set to `TRUE`", {
   #####
   # With learning rate
-  suppressWarnings(RNGversion("3.1.0"))
   set.seed(42)
   airq.ens.sparse <- pre(Ozone ~ ., data=airquality, ntrees = 10, sparse = TRUE)
   
   expect_equal(
     predict(airq.ens.sparse, type = "link", newdata = airquality[1:10, ]),
     predict(airq.ens.sparse, type = "link")[1:10])
-})
+})
\ No newline at end of file
